#include <vector>
#include <string>
#include <iostream>
#include <fstream>
#include "imprimir.h"

int main(int argc, char *argv[])
{
    if (argc < 2) {
        std::cerr << "Error: Argumentos insuficientes, indicar un nombre "
                  << "de fichero para abrir y leer." << std::endl;
        return -1;
    }
    
    // Declaramos un fichero de entrada y lo abrimos como fichero de lectura.
    std::ifstream fichero(argv[1]);

    if (!fichero) {
        std::cerr << "Error abriendo fichero " << argv[1] << std::endl;
        return -1;
    }

    // Leemos el fichero en el vector incial.
    std::vector<std::string> texto;
    while (!fichero.eof()) {
        std::string palabra;
        fichero >> palabra;
        if (!fichero.fail())
            texto.push_back(palabra);
    }

    // Ahora creamos el vector de vectores de palabras que se nos pide.
    
    typedef std::vector<std::vector<std::string> > Frases;
    Frases frases;
    // Este iterador apunta a la frase en la que estamos insertando las
    // palabras actualmente. Al principio el vector esta vaco, por eso
    // lo inicializamos a end.
    Frases::iterator frase = frases.end();

    for (std::vector<std::string>::const_iterator p = texto.begin();
         p != texto.end(); ++p) {
        if (frase == frases.end()) {
            // Esto quiere decir que debemos insertar un vector nuevo
            // en frases para insertar la siguiente palabra.
            frases.resize(frases.size() + 1);
            // El iterador se inicializa al ltimo elemento.
            frase = --frases.end();
        }

        // Insertamos la palabra en la frase.
        frase->push_back(*p);

        // Ahora comprobamos si esta palabra indica un final de frase.
        // La clase string tambin declara iteradores.
        if (*(p->rbegin()) == '.') {
            // Al pasar a la siguiente posicin de este iterador nos moveremos
            // a end. As en la siguiente iteracin (si hay una siguiente)
            // se crear el vector para la neuva frase.
            ++frase;
        }
    }
    // Observar que la contruccin del bucle asegura que frases no contiene
    // ningn vector vaco espreo al final.

    for (size_t i = 1; i <= frases.size(); ++i)
        std::cout << "Frase " << i << ": " << frases[i - 1] << std::endl;
}
