#include <vector>
#include <iostream>

// Una matriz es un vector de vectores con organizacin por filas.
typedef std::vector<std::vector<double> > Matriz;

Matriz multiplicar(const Matriz &p, const Matriz &q)
{
    // Primero comprobamos que las matrices p y q son efectivamente matrices
    // y que se puede multiplicar.
    size_t n = p.size();
    if (n == 0 || q.size() == 0) {
        std::cerr << "Las matrices deben tener al menos un elemento" 
                  << std::endl;
        return Matriz();
    }
    size_t m = p[0].size();
    size_t o = q[0].size();
    for (size_t i = 0; i < n; ++i) {
        if (p[i].size() != m){
            std::cerr << "Las matrices no son consistentes" << std::endl;
            return Matriz();
        }
    }
    if (q.size() != m) {
        std::cerr << "Las matrices no son consistentes" << std::endl;
        return Matriz();
    }
    for (size_t i = 0; i < m; ++i) {
        if (q[i].size() != o) {
            std::cerr << "Las matrices no son consistentes" << std::endl;
            return Matriz();
        }
    }

    // Redimensionamos la matriz resultado para que contenga n filas
    Matriz resultado;
    resultado.resize(n);
    for (size_t i = 0; i < n; ++i) {
        for (size_t j = 0; j < o; ++j) {
            double producto = 0;
            for (size_t k = 0; k < m; ++k) {
                producto += p[i][k] * q[k][j];
            }
            resultado[i].push_back(producto);
        }
    }
            
    return resultado;
}

void imprime(const Matriz &m)
{
    for (size_t i = 0; i < m.size(); ++i) {
        if (i != 0)
            std::cout << ' ';
        else
            std::cout << '[';
        for (size_t j = 0; j < m[i].size(); ++j) {
            std::cout << m[i][j];
            if (j != m[i].size() - 1) 
                std::cout << '\t';
        }
        if (i == m.size() - 1)
            std::cout << ']';
        std::cout << std::endl;
    }
}


int main(int argc, char *argv[])
{
    Matriz m1;
    m1.resize(2);
    m1[0].resize(3);
    m1[1].resize(3);
    m1[0][0] = 1.2; m1[0][1] = 0.6; m1[0][2] = -1.2;
    m1[1][0] = 3.0; m1[1][1] = -0.1; m1[1][2] = -0.8;


    Matriz m2;
    m2.resize(3);
    m2[0].resize(3);
    m2[1].resize(3);
    m2[2].resize(3);
    m2[0][0] = 0.4; m2[0][1] = -0.1; m2[0][2] = -1.2;
    m2[1][0] = 4.7; m2[1][1] = 0.35; m2[1][2] = 2.3;
    m2[2][0] = -1.5; m2[2][1] = 0.95; m2[2][2] = -1.77;

    imprime(m1);
    std::cout << std::endl;
    imprime(m2);
    std::cout << std::endl;

    Matriz r = multiplicar(m1, m2);
    imprime(r);
}
